
# Filester: generic, file based utilities and helpers
- [Overview](#Overview)
- [Installing from PyPI](#Installing-from-PyPI)

## Overview
[Filester](https://github.com/loum/filester) is a simple toolkit of common file based utilities that I
found re-using in all of my Python projects.  Basic tasks such as atomic file copy, move and delete that have been
tested and just work.

The complete list of file-based helpers can be found at [https://loum.github.io/filester/](https://loum.github.io/filester/)

## Installing from PyPI
```
pip install filester
```

---
[top](#Filester:-generic,-file-based-utilities-and-helpers)
